@@ -15,13 +15,13 @@
 
 from __future__ import annotations
 
-import base64
 import io
 import logging
 import pydoc
 import traceback
 from ast import PyCF_ALLOW_TOP_LEVEL_AWAIT, PyCF_ONLY_AST, PyCF_TYPE_COMMENTS
 from asyncio import Future
+from base64 import b85decode, b85encode
 from inspect import CO_COROUTINE  # pylint: disable=no-name-in-module
 from types import TracebackType
 from typing import Any
@@ -221,9 +221,7 @@ class Backdoor(APIRequestHandler):
                 else None
             )
             if session_pickle:
-                session = pickle.loads(
-                    base64.b64decode(session_pickle.encode("utf-8"))
-                )
+                session = pickle.loads(b85decode(session_pickle))
                 for key, value in session.items():
                     try:
                         session[key] = pickle.loads(value)
@@ -247,7 +245,7 @@ class Backdoor(APIRequestHandler):
     async def backup_session(self) -> bool:
         """Backup a session using Redis and return whether it succeeded."""
         session_id: None | str = self.request.headers.get("X-Backdoor-Session")
-        if not (self.redis and session_id in self.sessions):
+        if not (EVENT_REDIS.is_set() and session_id in self.sessions):
             return False
         session: dict[str, Any] = self.sessions[session_id].copy()
         session["self"] = None
@@ -262,7 +260,7 @@ class Backdoor(APIRequestHandler):
             await self.redis.setex(
                 f"{self.redis_prefix}:backdoor-session:{session_id}",
                 60 * 60 * 24 * 7,  # time to live in seconds (1 week)
-                base64.b64encode(pickle.dumps(session, PICKLE_PROTOCOL)),
+                b85encode(pickle.dumps(session, PICKLE_PROTOCOL)),
             )
         )
 
