@@ -171,7 +171,6 @@ async def continuation_string(
 
 
 ValueDict = dict[str, str | int | bool]
-#                  euro,mark, ost, schwarz
 ValuesTuple = tuple[int, int, int, int]
 
 
@@ -225,8 +224,7 @@ class CurrencyConverter(HTMLRequestHandler):
                 },
             )
             if replace_url_with != self.request.full_url():
-                self.redirect(replace_url_with)
-                return
+                return self.redirect(replace_url_with)
 
         await self.render(
             "pages/converter.html",
@@ -243,7 +241,7 @@ class CurrencyConverter(HTMLRequestHandler):
         arg_list: list[tuple[int, str, str]] = []
 
         for _i, key in enumerate(KEYS):
-            num_str = self.get_argument(name=key, default=None)
+            num_str = self.get_argument(key, None)
             if num_str is not None:
                 arg_list.append((_i, key, num_str))
         # print(arg_list)
