@@ -16,7 +16,7 @@
 from __future__ import annotations
 
 import os
-from functools import cache
+from functools import lru_cache
 
 import orjson as json
 
@@ -57,7 +57,7 @@ def get_file_names_and_languages() -> tuple[frozenset[str], frozenset[str]]:
 FILE_NAMES, LANGUAGES = get_file_names_and_languages()
 
 
-@cache
+@lru_cache(10)
 def get_words(file_name: str) -> frozenset[str]:
     """Get the words with the file_name and return them."""
     with open(
@@ -66,7 +66,7 @@ def get_words(file_name: str) -> frozenset[str]:
         return frozenset(file.read().splitlines())
 
 
-@cache
+@lru_cache(10)
 def get_letters(file_name: str) -> dict[str, int]:
     """Get the letters dict with the file_name and return it."""
     with open(
