@@ -54,6 +54,7 @@ def get_module_info() -> ModuleInfo:
         short_name="Host-Info",
         description="Informationen über den Host-Server dieser Webseite",
         path="/host-info",
+        aliases=("/server-info",),
         sub_pages=(
             PageInfo(
                 name="Howost-Infowmationyen",
@@ -121,7 +122,7 @@ class UwUHostInfo(HTMLRequestHandler):
         Use UwUFetch to genyewate the page.
         """
         cache_enabwed = int(
-            head or not self.get_bool_argument("cache_disabled", default=False)
+            head or not self.get_bool_argument("cache_disabled", False)
         )
 
         if UWUFETCH_PATH:
@@ -134,13 +135,13 @@ class UwUHostInfo(HTMLRequestHandler):
         if not UWUFETCH_PATH or wetuwn_code == 127:
             raise HTTPEwwow(
                 503,
-                reason="Sowwy. This sewvew h-hasn't instawwed UwUFetch.",
+                reason="This sewvew h-hasn't instawwed UwUFetch",
             )
 
         if wetuwn_code:
             raise HTTPEwwow(
                 500,
-                reason=f"UwUFetch has exited with wetuwn code {wetuwn_code}.",
+                reason=f"UwUFetch has exited with wetuwn code {wetuwn_code}",
             )
         if head:
             return
