@@ -17,7 +17,6 @@
 from __future__ import annotations
 
 import asyncio
-import base64
 import configparser
 import importlib
 import logging
@@ -28,6 +27,7 @@ import ssl
 import sys
 import types
 from asyncio.runners import _cancel_all_tasks  # type: ignore
+from base64 import b64encode
 from collections.abc import Callable, Coroutine
 from hashlib import sha256
 from multiprocessing import process
@@ -49,7 +49,7 @@ from redis.asyncio import (
 )
 from tornado.httpserver import HTTPServer
 from tornado.log import LogFormatter
-from tornado.web import Application, RedirectHandler, StaticFileHandler
+from tornado.web import Application, RedirectHandler
 
 from . import (
     CONTAINERIZED,
@@ -64,20 +64,24 @@ from . import (
 from .contact.contact import apply_contact_stuff_to_app
 from .quotes import AUTHORS_CACHE, QUOTES_CACHE, WRONG_QUOTES_CACHE
 from .utils import static_file_handling
-from .utils.request_handler import BaseRequestHandler, NotFoundHandler
+from .utils.base_request_handler import BaseRequestHandler
+from .utils.request_handler import NotFoundHandler
+from .utils.static_file_handling import StaticFileHandler
 from .utils.utils import Handler, ModuleInfo, Permission, Timer, time_function
 
-IGNORED_MODULES = [
+IGNORED_MODULES = {
+    "backdoor.backdoor_client",
     "patches.*",
-    "static.*",
-    "templates.*",
-    "utils.utils",
-    "utils.static_file_handling",
-    "swapped_words.sw_config_file",
     "quotes.quotes_image",
     "quotes.share_page",
-    "backdoor.backdoor_client",
-]
+    "static.*",
+    "swapped_words.sw_config_file",
+    "templates.*",
+    "utils.base_request_handler",
+    "utils.braille",
+    "utils.static_file_handling",
+    "utils.utils",
+}
 
 CONFIG = configparser.ConfigParser(interpolation=None)
 CONFIG.read("config.ini", encoding="utf-8")
@@ -277,6 +281,10 @@ def apply_config_to_app(
     """Apply the config (from the config.ini file) to the application."""
     app.settings["CONFIG"] = config
 
+    app.settings["compress_response"] = config.getboolean(
+        "GENERAL", "COMPRESS_RESPONSE", fallback=False
+    )
+
     app.settings["cookie_secret"] = config.get(
         "GENERAL", "COOKIE_SECRET", fallback=b"xyzzy"
     )
@@ -450,9 +458,9 @@ def setup_apm(app: Application) -> None:
         f"environment:'{app.settings['ELASTIC_APM']['ENVIRONMENT']}',"
         "})"
     )
-    app.settings["ELASTIC_APM"]["INLINE_SCRIPT_HASH"] = base64.b64encode(
+    app.settings["ELASTIC_APM"]["INLINE_SCRIPT_HASH"] = b64encode(
         sha256(
-            app.settings["ELASTIC_APM"]["INLINE_SCRIPT"].encode("utf-8")
+            app.settings["ELASTIC_APM"]["INLINE_SCRIPT"].encode("ascii")
         ).digest()
     ).decode("ascii")
     app.settings["ELASTIC_APM_CLIENT"] = ElasticAPM(app).client
@@ -477,13 +485,13 @@ def setup_app_search(app: Application) -> None:
     )
 
 
-def setup_elasticsearch(app: Application) -> None:
+def setup_elasticsearch(app: Application) -> None | AsyncElasticsearch:
     """Setup Elasticsearch."""  # noqa: D401
     config = app.settings["CONFIG"]
     if not config.getboolean("ELASTICSEARCH", "ENABLED", fallback=False):
         app.settings["ELASTICSEARCH"] = None
-        return
-    app.settings["ELASTICSEARCH"] = AsyncElasticsearch(
+        return None
+    elasticsearch = AsyncElasticsearch(
         cloud_id=config.get("ELASTICSEARCH", "CLOUD_ID", fallback=None),
         hosts=tuple(
             host.strip()
@@ -514,6 +522,8 @@ def setup_elasticsearch(app: Application) -> None:
             "accept": "application/vnd.elasticsearch+json; compatible-with=7"
         },
     )
+    app.settings["ELASTICSEARCH"] = elasticsearch
+    return elasticsearch
 
 
 async def check_elasticsearch(app: Application) -> None:
@@ -570,13 +580,13 @@ async def setup_elasticsearch_configs(  # noqa: C901
                 continue
 
             body = orjson.loads(
-                path.read_text("utf-8").replace("{prefix}", prefix)
+                path.read_bytes().replace(b"{prefix}", prefix.encode("ascii"))
             )
 
             name = f"{prefix}-{str(path.relative_to(base_path))[:-5].replace('/', '-')}"
 
             try:
-                if i == 0:  # pylint: disable=compare-to-zero
+                if what == "ingest_pipelines":
                     current = await get(id=name)
                     current_version = current[name].get("version", 1)
                 else:
@@ -589,25 +599,25 @@ async def setup_elasticsearch_configs(  # noqa: C901
                 current_version = 0
 
             if current_version < body.get("version", 1):
-                if i == 0:  # pylint: disable=compare-to-zero
+                if what == "ingest_pipelines":
                     await put(id=name, body=body)
                 else:
                     await put(name=name, body=body)
             elif current_version > body.get("version", 1):
                 logger.warning(
-                    "%s has older version %s. Current version is %s!",
+                    "%s has version %s. The version in Elasticsearch is %s!",
                     path,
                     body.get("version", 1),
                     current_version,
                 )
 
 
-def setup_redis(app: Application) -> None:
+def setup_redis(app: Application) -> None | Redis[str]:
     """Setup Redis."""  # noqa: D401
     config = app.settings["CONFIG"]
     if not config.getboolean("REDIS", "ENABLED", fallback=False):
         app.settings["REDIS"] = None
-        return
+        return None
     kwargs = {
         "db": config.getint("REDIS", "DB", fallback=0),
         "username": config.get("REDIS", "USERNAME", fallback=None),
@@ -651,15 +661,15 @@ def setup_redis(app: Application) -> None:
                     ),
                 }
             )
-    app.settings["REDIS"] = Redis(
-        connection_pool=BlockingConnectionPool(**kwargs)
-    )
+    redis: Redis[str] = Redis(connection_pool=BlockingConnectionPool(**kwargs))
+    app.settings["REDIS"] = redis
+    return redis
 
 
 async def check_redis(app: Application) -> None:
     """Check Redis."""
     while True:  # pylint: disable=while-used
-        redis: Redis = cast(Redis, app.settings.get("REDIS"))  # type: ignore[type-arg]
+        redis: Redis[str] = cast("Redis[str]", app.settings.get("REDIS"))
         try:
             await redis.ping()
         except Exception as exc:  # pylint: disable=broad-except
@@ -685,6 +695,8 @@ def signal_handler(  # noqa: D103
     # pylint: disable=unused-argument, missing-function-docstring
     if signalnum in {signal.SIGINT, signal.SIGTERM}:
         EVENT_SHUTDOWN.set()
+    if hasattr(signal, "SIGHUP") and signalnum == signal.SIGHUP:
+        EVENT_SHUTDOWN.set()
 
 
 def install_signal_handler() -> None:
@@ -719,7 +731,7 @@ def main() -> None | int | str:  # noqa: C901
     ).split(","):
         module_name = module_name.strip()  # pylint: disable=redefined-loop-name
         if len(module_name) > 0:
-            IGNORED_MODULES.append(module_name)
+            IGNORED_MODULES.add(module_name)
 
     app = make_app()
     if isinstance(app, str):
