@@ -42,19 +42,13 @@ def get_caller_name() -> None | str:  # noqa: D103
             return None
         name = frame.f_globals["__name__"]
         while (  # pylint: disable=while-used
-            frame
-            and "__name__" in frame.f_globals
-            and frame.f_globals["__name__"] == name
+            frame and frame.f_globals.get("__name__") == name
         ):
             frame = frame.f_back
-        caller = (
-            frame.f_globals["__name__"]
-            if frame and "__name__" in frame.f_globals
-            else None
-        )
+        caller = frame.f_globals.get("__name__") if frame else None
     finally:
         del frame
-    return caller  # type: ignore[no-any-return]
+    return caller
 
 
 def dumps(  # noqa: C901, D103
@@ -97,14 +91,13 @@ def dumps(  # noqa: C901, D103
         )
         default = _.default
     output = orjson.dumps(obj, default, option)
-    if indent is not None and indent not in {2, "  "}:
+    if indent not in {None, 2, "  "}:
         if isinstance(indent, int):
             indent = " " * indent
+        indent_bytes = str(indent).encode("utf-8")
         output = re.sub(
             rb"(?m)^\s+",
-            lambda match: match.group(0).replace(
-                b"  ", str(indent).encode("utf-8")
-            ),
+            lambda match: len(match[0]) // 2 * indent_bytes,
             output,
         )
     return output.decode("utf-8")
