@@ -40,22 +40,23 @@ def get_module_info() -> ModuleInfo:
 class SettingsPage(HTMLRequestHandler):
     """The request handler for the settings page."""
 
-    def get(self, *, head: bool = False) -> None:
+    async def get(self, *, head: bool = False) -> None:
         """Handle GET requests to the settings page."""
         if head:
             return
-        self.render(
+        await self.render(
             "pages/settings.html",
             theme_name=self.get_theme(),
             themes=THEMES,
             no_3rd_party_default=self.get_no_3rd_party_default(),
             dynload=self.get_dynload(),
+            openmoji=self.get_openmoji(),
             save_in_cookie=self.get_bool_argument("save_in_cookie", True),
             show_token_input=self.get_bool_argument("auth", False),
             token="",
         )
 
-    def post(self) -> None:
+    async def post(self) -> None:
         """Handle POST requests to the settings page."""
         theme: str = self.get_argument("theme", None) or "default"
         no_3rd_party: bool = self.get_bool_argument(
@@ -63,10 +64,11 @@ class SettingsPage(HTMLRequestHandler):
         )
         dynload: bool = self.get_bool_argument("dynload", False)
         save_in_cookie: bool = self.get_bool_argument("save_in_cookie", False)
+        openmoji: bool = self.get_bool_argument("openmoji", False)
 
-        token = self.get_argument("access_token", None)
+        token = self.get_argument("access_token", "")
         access_token: None | str = (
-            b64encode(token.encode("utf-8")).decode("utf-8") if token else None
+            b64encode(token.encode("utf-8")).decode("ascii") if token else None
         )
 
         if save_in_cookie:
@@ -75,6 +77,7 @@ class SettingsPage(HTMLRequestHandler):
             self.set_cookie("theme", theme)
             self.set_cookie("no_3rd_party", bool_to_str(no_3rd_party))
             self.set_cookie("dynload", bool_to_str(dynload))
+            self.set_cookie("openmoji", bool_to_str(openmoji))
             replace_url_with = self.fix_url(
                 self.request.full_url(),
                 dynload=None,
@@ -82,29 +85,31 @@ class SettingsPage(HTMLRequestHandler):
                 theme=None,
                 save_in_cookie=None,
                 access_token=None,
+                openmoji=None,
             )
         else:
             replace_url_with = self.fix_url(
                 self.request.full_url(),
                 dynload=dynload,
                 no_3rd_party=no_3rd_party,
+                openmoji=openmoji,
                 theme=theme,
                 save_in_cookie=False,
                 access_token=access_token,
             )
 
         if replace_url_with != self.request.full_url():
-            self.redirect(replace_url_with)
-            return
+            return self.redirect(replace_url_with)
 
-        self.render(
+        await self.render(
             "pages/settings.html",
             theme_name=theme,
             themes=THEMES,
             no_3rd_party=no_3rd_party,
             no_3rd_party_default=self.get_no_3rd_party_default(),
             dynload=dynload,
+            openmoji=openmoji,
             save_in_cookie=save_in_cookie,
             show_token_input=token or self.get_bool_argument("auth", False),
-            token=token or "",
+            token=token,
         )
