@@ -67,7 +67,7 @@ def mark_query(text: str, query: None | str) -> str:
     for word in query.split(" "):
         text = re.sub(
             word,
-            lambda match: f'<div class="marked">{match.group()}</div>',
+            lambda match: f'<div class="marked">{match[0]}</div>',
             text,
             flags=re.RegexFlag.IGNORECASE,
         )
@@ -105,7 +105,7 @@ class HeaderInfo(Info):
         query: None | str = None,
     ) -> str:
         """
-        Return a HTML element with the tag and the content of the HeaderInfo.
+        Return an HTML element with the tag and the content of the HeaderInfo.
 
         The HTML element gets an id and a href with a # to
         itself based on the text content.
