@@ -226,7 +226,7 @@ class SoundboardHTMLHandler(HTMLRequestHandler):
             return persons_list, None
 
         if path in {"search", "suche"}:
-            query = self.get_argument("q", default="")
+            query = self.get_argument("q", "")
             if not query:
                 return MAIN_PAGE_INFO, query
 
@@ -269,5 +269,5 @@ class SoundboardRSSHandler(SoundboardHTMLHandler):
                 found=True,
                 rss_str=rss_str,
             )
-        self.set_status(404, reason="Feed not found.")
+        self.set_status(404, reason="Feed not found")
         return await self.render("rss/soundboard.xml", found=False, rss_str="")
