@@ -17,6 +17,7 @@ from __future__ import annotations
 
 import base64
 import os
+from asyncio import Future
 
 from tornado.web import HTTPError
 
@@ -54,7 +55,7 @@ def get_module_info() -> ModuleInfo:
 
 
 # the max char count of the text to process
-MAX_CHAR_COUNT: int = 32768
+MAX_CHAR_COUNT = 32768
 
 with open(os.path.join(DIR, "config.sw"), encoding="utf-8") as file:
     DEFAULT_CONFIG: SwappedWordsConfig = SwappedWordsConfig(file.read())
@@ -80,14 +81,14 @@ class SwappedWords(HTMLRequestHandler):
 
     def handle_text(
         self, text: str, config_str: None | str, use_default_config: bool
-    ) -> None:
+    ) -> Future[None]:
         """Use the text to display the HTML page."""
         check_text_too_long(text)
 
         if config_str is None:
             cookie = self.get_cookie(
-                name="swapped-words-config",
-                default=None,
+                "swapped-words-config",
+                None,
             )
             if cookie is not None:
                 # decode the base64 text
@@ -116,7 +117,7 @@ class SwappedWords(HTMLRequestHandler):
             )
         except InvalidConfigError as exc:
             self.set_status(400)
-            self.render(
+            return self.render(
                 "pages/swapped_words.html",
                 text=text,
                 output="",
@@ -125,7 +126,7 @@ class SwappedWords(HTMLRequestHandler):
                 error_msg=str(exc),
             )
         else:  # everything went well
-            self.render(
+            return self.render(
                 "pages/swapped_words.html",
                 text=text,
                 output=sw_config.swap_words(text),
@@ -134,22 +135,22 @@ class SwappedWords(HTMLRequestHandler):
                 error_msg=None,
             )
 
-    def get(
+    async def get(
         self, *, head: bool = False  # pylint: disable=unused-argument
     ) -> None:
         """Handle GET requests to the swapped words page."""
-        self.handle_text(
-            self.get_argument("text", default=None) or "",
-            self.get_argument("config", default=None),
-            self.get_bool_argument("reset", default=False),
+        await self.handle_text(
+            self.get_argument("text", ""),
+            self.get_argument("config", None),
+            self.get_bool_argument("reset", False),
         )
 
-    def post(self) -> None:
+    async def post(self) -> None:
         """Handle POST requests to the swapped words page."""
-        self.handle_text(
-            self.get_argument("text") or "",
-            self.get_argument("config", default=None),
-            self.get_bool_argument("reset", default=False),
+        await self.handle_text(
+            self.get_argument("text"),
+            self.get_argument("config", None),
+            self.get_bool_argument("reset", False),
         )
 
 
@@ -162,11 +163,11 @@ class SwappedWordsAPI(APIRequestHandler):
         self, *, head: bool = False  # pylint: disable=unused-argument
     ) -> None:
         """Handle GET requests to the swapped words API."""
-        text = self.get_argument("text", default=None) or ""
+        text = self.get_argument("text", "")
 
         check_text_too_long(text)
 
-        config_str = self.get_argument("config", default=None)
+        config_str = self.get_argument("config", None)
         return_config = self.get_bool_argument("return_config", False)
         try:
             sw_config = (
@@ -177,9 +178,7 @@ class SwappedWordsAPI(APIRequestHandler):
 
             if return_config:
 
-                minify_config = self.get_bool_argument(
-                    "minify_config", default=True
-                )
+                minify_config = self.get_bool_argument("minify_config", True)
                 return await self.finish_dict(
                     text=text,
                     return_config=True,
