@@ -19,21 +19,27 @@ import logging
 import math
 import re
 import time
+from typing import TypedDict
 
 from elasticsearch import AsyncElasticsearch
 from tornado.web import HTTPError, RedirectHandler
 
 from .. import EPOCH, EVENT_ELASTICSEARCH, NAME, START_TIME
-from ..utils.request_handler import (
-    APIRequestHandler,
-    BaseRequestHandler,
-    HTMLRequestHandler,
-)
+from ..utils.base_request_handler import BaseRequestHandler
+from ..utils.request_handler import APIRequestHandler, HTMLRequestHandler
 from ..utils.utils import ModuleInfo
 
 logger = logging.getLogger(__name__)
 
 
+class AvailabilityDict(TypedDict):  # noqa: D101
+    # pylint: disable=missing-class-docstring
+    up: int
+    down: int
+    total: int
+    percentage: None | float
+
+
 def get_module_info() -> ModuleInfo:
     """Create and return the ModuleInfo for this module."""
     return ModuleInfo(
@@ -100,13 +106,14 @@ async def get_availability_data(
             "down": {"sum": {"field": "summary.down"}},
         },
     )
+    data.setdefault("aggregations", {"up": {"value": 0}, "down": {"value": 0}})
     return (
         int(data["aggregations"]["up"]["value"]),
         int(data["aggregations"]["down"]["value"]),
     )
 
 
-def get_availability_dict(up: int, down: int) -> dict[str, int | float | None]:
+def get_availability_dict(up: int, down: int) -> AvailabilityDict:
     """Get the availability data as a dict."""
     # pylint: disable=invalid-name
     return {
@@ -165,7 +172,7 @@ class AvailabilityChartHandler(BaseRequestHandler):
 
     async def get(self, *, head: bool = False) -> None:
         """Handle GET requests."""
-        availability = self.get_argument("a", default=None)
+        availability = self.get_argument("a", None)
         if not availability:
             if not EVENT_ELASTICSEARCH.is_set():
                 raise HTTPError(503)
