@@ -20,13 +20,13 @@ import os
 import random
 import re
 import time
-from base64 import urlsafe_b64encode
+from base64 import b85encode
 from collections.abc import Callable, Sequence
 from dataclasses import dataclass, field
 from datetime import datetime
 from enum import IntFlag
 from functools import cache
-from ipaddress import ip_address, ip_network
+from ipaddress import IPv4Address, IPv6Address, ip_address, ip_network
 from typing import IO, Any, TypeVar, Union
 from urllib.parse import SplitResult, parse_qsl, urlencode, urlsplit, urlunsplit
 
@@ -38,20 +38,6 @@ from tornado.web import HTTPError, RequestHandler
 
 from .. import STATIC_DIR
 
-# All the text content types used by the website
-TEXT_CONTENT_TYPES = {
-    "application/javascript",
-    "application/json",
-    "application/rss+xml",
-    "application/x-ndjson",
-    "application/xml",
-    "application/yaml",
-    "image/svg+xml",
-    "text/html",
-    "text/markdown",
-    "text/plain",
-}
-
 T = TypeVar("T")
 
 # pylint: disable=consider-alternative-union-syntax
@@ -307,12 +293,10 @@ def emojify(string: str) -> str:
     """Emojify a given string."""
     string = re.sub(
         r"[a-zA-Z]+",
-        lambda match: "\u200C".join(country_code_to_flag(match.group(0))),
+        lambda match: "\u200C".join(country_code_to_flag(match[0])),
         replace_umlauts(string),
     )
-    string = re.sub(
-        r"[0-9#*]+", lambda match: f"{'⃣'.join(match.group(0))}⃣", string
-    )
+    string = re.sub(r"[0-9#*]+", lambda match: f"{'⃣'.join(match[0])}⃣", string)
     return (
         string.replace("!?", "⁉")
         .replace("!!", "‼")
@@ -399,23 +383,25 @@ def get_themes() -> tuple[str, ...]:
     )
 
 
-def hash_bytes_b64(text: bytes, size: int = 32) -> str:
-    """Hash bytes with blake and return the url-safe base64 representation."""
-    hash_: bytes = blake3(text).digest(size)
-    return urlsafe_b64encode(hash_).decode("ascii")
+def hash_bytes(text: bytes, size: int = 32) -> str:
+    """Hash bytes with BLAKE3 and return the Base85 representation."""
+    digest: bytes = blake3(text).digest(size)
+    return b85encode(digest).decode("ascii")
 
 
-def hash_ip(ip: str) -> str:  # pylint: disable=invalid-name
+def hash_ip(address: str | IPv4Address | IPv6Address) -> str:
     """Hash an IP address."""
-    return hash_bytes_b64(
-        ip.encode("ascii")
-        + blake3(datetime.utcnow().date().isoformat().encode("ascii")).digest()
+    if not isinstance(address, IPv4Address | IPv6Address):
+        address = ip_address(address)
+    return hash_bytes(
+        blake3(datetime.utcnow().date().isoformat().encode("ascii")).digest()
+        + address.packed
     )
 
 
-def length_of_match(_m: re.Match[str]) -> int:
+def length_of_match(match: re.Match[str]) -> int:
     """Calculate the length of the regex match and return it."""
-    span = _m.span()
+    span = match.span()
     return span[1] - span[0]
 
 
@@ -440,6 +426,14 @@ def name_to_id(val: str) -> str:
     ).strip("-")
 
 
+def remove_suffix_ignore_case(string: str, suffix: str, /) -> str:
+    """Remove a suffix without caring about the case."""
+    if string.lower().endswith(suffix.lower()):
+        return string[: -len(suffix)]
+
+    return string
+
+
 def normalized_levenshtein(string1: str, string2: str) -> float:
     """Calculate the normalized Levenshtein distance between two strings."""
     return float(distance(string1, string2)) / max(len(string1), len(string2))
@@ -468,6 +462,16 @@ def replace_umlauts(string: str) -> str:
     )
 
 
+def emoji2code(emoji: str) -> str:
+    """Convert an emoji to the hexcodes of it."""
+    return "-".join(f"{ord(c):x}" for c in emoji).upper()
+
+
+def create_emoji_html(emoji: str, emoji_url: str) -> str:
+    """Create an HTML element that can be used to display an emoji."""
+    return f'<img src="{emoji_url}" alt="{emoji}" class="emoji">'
+
+
 async def run(
     program: str,
     *args: str,
